@@ -460,7 +460,7 @@ class Request(object):
     @staticmethod
     def __getParameterTree(hash_reply, protobuf_types, socket):
         tree_hash = hash_reply.get()
-        path = tempfile.gettempdir() + '/' + str(tree_hash.hash)
+        path = os.sep.join([tempfile.gettempdir(), str(tree_hash.hash)])
         tree = Request.loadParameterTreeFile(path, protobuf_types)
         if tree:
             logger.debug('Found parameter tree in the cache')
